@@ -1,4 +1,7 @@
 from .device_operation_mode import DeviceOperationModeEnum
 from .ip_address_version import IpAddressVersionEnum
+from .lacp_status import LacpStatusEnum
 from .mac_address_version import MacAddressVersionEnum
+from .port_config_mode import PortConfigModeEnum
+from .port_trunk_type import PortTrunkTypeEnum
 from .time_server_protocol import TimeServerProtocolEnum
