@@ -1,6 +1,6 @@
 from enum import Enum
 
 
-class TimeServerProtocol(str, Enum):
+class TimeServerProtocolEnum(str, Enum):
     TSP_NTP = "TSP_NTP"
     TSP_SNTP = "TSP_SNTP"
