@@ -1,3 +1,3 @@
 from .ip_address import IpAddressModel
 from .mac_address import MacAddress
-from .network_host import NetworkHost
+from .network_host import NetworkHostModel
